@@ -3,7 +3,7 @@ package MOP4Import::Declare;
 use 5.010;
 use strict;
 use warnings qw(FATAL all NONFATAL misc);
-our $VERSION = '0.071_003'; BEGIN {$VERSION = '0.071_003'};
+our $VERSION = '0.071_004'; BEGIN {$VERSION = '0.071_004'};
 use Carp;
 use mro qw/c3/;
 
@@ -503,8 +503,9 @@ sub declare___field :MetaOnly {
 
   # Create accessor for all public fields.
   if ($name =~ /^[a-z]/i and not $fs->{no_getter}) {
-    if (my $sym = MOP4Import::Util::symtab($opts->{objpkg})->{$name}) {
-      if (*{$sym}{CODE}) {
+    if (my $entry = MOP4Import::Util::symtab($opts->{objpkg})->{$name}) {
+      if (ref $entry eq 'CODE'
+          or ref \$entry eq 'GLOB' and *{$entry}{CODE}) {
         croak "Accessor $opts->{objpkg}::$name is redefined!\nIf you really want to define the accessor by hand, please specify fields spec like: [$name => no_getter => 1, ...].";
       }
     }
